; Project name	:	FixYMF
; Description	:	Functions to print strings.

;
; FixYMF
; Copyright (C) 2022 by Tomi Tilli
;
; Uses assembly libraries from XTIDE Universal BIOS and Associated Tools
; Copyright (C) 2009-2010 by Tomi Tilli, 2011-2021 by XTIDE Universal BIOS Team.
;
; This program is free software; you can redistribute it and/or modify
; it under the terms of the GNU General Public License as published by
; the Free Software Foundation; either version 2 of the License, or
; (at your option) any later version.
;
; This program is distributed in the hope that it will be useful,
; but WITHOUT ANY WARRANTY; without even the implied warranty of
; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
; GNU General Public License for more details.
; Visit http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
;


;--------------------------------------------------------------------
; Print_SetCharacterOutputToSTDOUT
;	Parameters:
;		Nothing
;	Returns:
;		Nothing
;	Corrupts registers:
;		AX, BX, DI
;--------------------------------------------------------------------
Print_SetCharacterOutputToSTDOUT:
	mov		bl, ATTRIBUTES_NOT_USED
	mov		ax, DosCharOut
	JMP_DISPLAY_LIBRARY SetCharOutputFunctionFromAXwithAttribFlagInBL


;--------------------------------------------------------------------
; Use DOS standard output so strings can be redirected to a file.
;
; DosCharOut
;	Parameters:
;		AL:		Character to output
;	Returns:
;		Nothing
;	Corrupts registers:
;		AX, DX
;--------------------------------------------------------------------
DosCharOut:
	xchg	dx, ax
	mov		ah, WRITE_CHARACTER_TO_STANDARD_OUTPUT
	int		DOS_INTERRUPT_21h
	ret


;---------------------------------------------------------------------
; Print_FormatStringFromSIwithParameterInAX
; Print_FormatStringFromSIwithParametersInAXDX
; Print_FormatStringFromSIwithParametersInAXDXCX
;	Parameters:
;		AX:		Format parameter 1
;		DX:		Format parameter 2
;		CX:		Format parameter 3
;		SI:		Offset to format string
;	Returns:
;		Nothing
;	Corrupts registers:
;		AX, BP, DI
;--------------------------------------------------------------------
Print_FormatStringFromSIwithParameterInAX:
	mov		bp, sp
	push	ax
	jmp		JumpToFormatNullTerminatedStringFromSI

Print_FormatStringFromSIwithParametersInAXDX:
	mov		bp, sp
	push	ax
	push	dx
	jmp		JumpToFormatNullTerminatedStringFromSI

Print_FormatStringFromSIwithParametersInAXDXCX:
	mov		bp, sp
	push	ax
	push	dx
	push	cx
	; Fall to JumpToFormatNullTerminatedStringFromSI


;---------------------------------------------------------------------
; JumpToFormatNullTerminatedStringFromSI
;	Parameters:
;		BP:		SP before pushing parameters
;		CS:SI:	Ptr to format string
;	Returns:
;		Pushed parameters are cleaned from stack
;	Corrupts registers:
;		AX, DI
;--------------------------------------------------------------------
JumpToFormatNullTerminatedStringFromSI:
	JMP_DISPLAY_LIBRARY FormatNullTerminatedStringFromCSSI


;---------------------------------------------------------------------
; Print_NullTerminatedStringFromSI
;	Parameters:
;		CS:SI:	Ptr to string to display
;	Returns:
;		Nothing
;	Corrupts registers:
;		AX, DI
;--------------------------------------------------------------------
Print_NullTerminatedStringFromSI:
	JMP_DISPLAY_LIBRARY PrintNullTerminatedStringFromCSSI

